import { useState } from "react";
import { Box, Typography } from "@mui/material";

import Modal from "../../../components/Modal/Modal";
import Metric from "../../../components/Metric/Metric";
import GhostStyledIcon from "../../../components/Icon/GhostIcon";
import { PrimaryButton, SecondaryButton } from "../../../components/Button";

import { DecimalBigNumber } from "../../../helpers/DecimalBigNumber";
import { formatNumber, capitalize, shorten } from "../../../helpers";

import { forfeit, claim } from "../../../hooks/staking";

const ClaimConfirmationModal = (props) => {
    const [isPending, setIsPending] = useState(false);

    const confirm = async () => {
        setIsPending(true);

        switch (props.action.toUpperCase()) {
            case "FORFEIT":
                await forfeit(props.chainId, props.receiver);
                break;
            case "CLAIM":
                await claim(props.chainId, props.receiver, props.outputToken === "STNK");
                break;
            default:
                console.log("Unknown action")
        }

        setIsPending(false);
        props.onClose();
    }

    return (
        <Modal
            data-testid="claim-confirmation-modal"
            maxWidth="356px"
            topLeft={<></>}
            headerContent={
                <Box display="flex" flexDirection="row">
                    <Typography variant="h5">{`Confirm ${capitalize(props.action)}`}</Typography>
                </Box>
            }
            open={props.open}
            onClose={() => isPending ? {} : props.onClose()}
            minHeight={"100px"}
        >
            <Box display="flex" flexDirection="column">
                <Box display="flex" flexDirection="row" justifyContent="center" alignItems="center">
                    <Box display="flex" flexDirection="column">
                        <Metric
                            label={`Assets to ${shorten(props.receiver)}`}
                            metric={formatNumber(props.receiveAmount, 6)}
                            />
                        <Box display="flex" flexDirection="row" justifyContent="center">
                            <Typography>
                                {props.outputToken}
                            </Typography>
                        </Box>
                    </Box>
                </Box>

                <Box sx={{ marginTop: "2rem" }}>
                    <PrimaryButton
                        data-testid="claim-modal-button"
                        loading={isPending}
                        fullWidth
                        disabled={isPending}
                        onClick={() => confirm()}
                    >
                        Confirm
                    </PrimaryButton>
                </Box>
            </Box>
        </Modal>
    )
}

export default ClaimConfirmationModal;
