import {
    TableContainer,
    TableHead,
    TableBody,
    TableRow,
    TableCell,
    Table,
    Typography,
    Box,
    useMediaQuery,
} from "@mui/material";
import { useNavigate, createSearchParams } from "react-router-dom";

import Paper from "../../../components/Paper/Paper";
import { SecondaryButton } from "../../../components/Button";
import TokenStack from "../../../components/TokenStack/TokenStack";
import { DecimalBigNumber } from "../../../helpers/DecimalBigNumber";
import { formatCurrency } from "../../../helpers";

import { useLpValuation } from "../../../hooks/treasury";
import { useTotalSupply } from "../../../hooks/tokens";

import {
    DAI_ADDRESSES,
    FTSO_ADDRESSES,
    STNK_ADDRESSES,
    GHST_ADDRESSES,
    FTSO_DAI_LP_ADDRESSES,
} from "../../../constants/addresses";

const FarmPools = ({ chainId }) => {
    const isSmallScreen = useMediaQuery("(max-width: 775px)");

    const { totalSupply: daiFtsoUniTotalSupply } = useTotalSupply(chainId, FTSO_DAI_LP_ADDRESSES[chainId]);
    const daiFtsoUniValuation = useLpValuation(chainId, FTSO_DAI_LP_ADDRESSES[chainId], daiFtsoUniTotalSupply._value);

    const pools = [
        {
            icons: ["FTSO", "GDAI"],
            name: "FTSO-gDAI",
            dex: "Uniswap V2",
            url: "/dex/uniswap",
            tvl: daiFtsoUniValuation,
            params: createSearchParams({
                pool: "true",
                from: `${DAI_ADDRESSES[chainId]}`,
                to: `${FTSO_ADDRESSES[chainId]}`,
            })
        },
    ];

    if (isSmallScreen) {
        return (
            <>
                {pools.map((pool, id) => {
                    return (
                        <FarmPoolCard key={id} id={id} pool={pool} />
                    )
                })}
            </>
        )
    }

    return (
        <Paper headerText="Farm Pools" fullWidth enableBackground>
            <TableContainer>
                <Table aria-label="Available bonds" style={{ tableLayout: "fixed" }}>
                    <TableHead>
                        <TableRow>
                            <TableCell style={{ padding: "8px 0", width: "30%" }}>Asset</TableCell>
                            <TableCell style={{ padding: "8px 0", width: "30%" }}>TVL</TableCell>
                            <TableCell style={{ padding: "8px 0", width: "40%" }}></TableCell>
                        </TableRow>
                    </TableHead>

                    <TableBody>
                        {pools.map((pool, id) => {
                            return (
                                <FarmPoolRow key={id} id={id} pool={pool} />
                            )
                        })}
                    </TableBody>
                </Table>
            </TableContainer>
        </Paper>
    )
}

const FarmPoolCard = ({ id, pool }) => {
    return (
        <Paper enableBackground fullWidth>
            <Box id={id + `--bond`}>
                <Box display="flex" alignItems="center" flexDirection="column" gap="20px">
                    <Box display="flex" alignItems="center" gap="20px">
                        <TokenStack tokens={pool.icons} />
                        <Typography>{pool.name}</Typography>
                    </Box>

                    <Typography>{formatCurrency(pool.tvl, 2)}</Typography>

                    <SecondaryButton
                        fullWidth
                        sx={{ maxWidth: "320px" }}
                        href={pool.url}
                    >
                        Get on {pool.dex}
                    </SecondaryButton>
                </Box>
            </Box>
        </Paper>

    )
}

const FarmPoolRow = ({ id, pool }) => {
    const navigate = useNavigate();
    return (
        <TableRow key={id} id={id + `--pool`} data-testid={id + `--pool`}>
            <TableCell style={{ padding: "8px 0" }}>
                <Box display="flex" alignItems="center" gap="20px">
                    <TokenStack tokens={pool.icons} />
                    <Typography>{pool.name}</Typography>
                </Box>
            </TableCell>

            <TableCell style={{ padding: "8px 0" }}>
                <Typography>{formatCurrency(pool.tvl, 2)}</Typography>
            </TableCell>

            <TableCell style={{ display: "flex", justifyContent: "end", padding: "8px 0" }}>
                <SecondaryButton
                    fullWidth
                    sx={{ maxWidth: "320px" }}
                    onClick={() => navigate({ pathname: pool.url, search: pool.params.toString() })}
                >
                    Get on {pool.dex}
                </SecondaryButton>
            </TableCell>
        </TableRow>
    )
}

export default FarmPools;
