import { Box, Container, Grid, useMediaQuery, useTheme } from "@mui/material";
import { memo, useEffect, useMemo, useState } from "react";
import { Outlet, Route, Routes, useSearchParams } from "react-router-dom";
import ReactGA from "react-ga4";

import {
    TreasuryMarketCap,
    FatsoBacking,
    FatsoPrice,
    GhostPrice,
    CirculatingSupply,
    CurrentIndex,
} from "./components/Metric";
import TokenInfo from "./components/TokenInfo";

import Paper from "../../components/Paper/Paper";
import PageTitle from "../../components/PageTitle/PageTitle";
import SafariFooter from "../../components/SafariFooter/SafariFooter";

const MetricsDashboard = ({ chainId }) => {
    const theme = useTheme();
    const isMobileScreen = useMediaQuery("(max-width: 885px)");
    const isVeryMobileScreen = useMediaQuery("(max-width: 560px)");

    const xsCalculator = useMemo(() => {
        return isMobileScreen ? isVeryMobileScreen ? 12 : 6 : 4;
    }, [isMobileScreen, isVeryMobileScreen])

    return (
        <Box minHeight="calc(100vh - 135px)" display="flex" flexDirection="column" justifyContent="center">
            <Grid container spacing={1}>
                <Grid item xs={12}>
                    <Paper fullWidth enableBackground>
                        <Grid container spacing={2}>
                            <Grid item xs={xsCalculator}>
                                <TreasuryMarketCap chainId={chainId} />
                            </Grid>
                            <Grid item xs={xsCalculator}>
                                <FatsoPrice chainId={chainId} />
                            </Grid>
                            <Grid item xs={xsCalculator}>
                                <GhostPrice chainId={chainId} />
                            </Grid>
                            <Grid item xs={xsCalculator}>
                                <CirculatingSupply chainId={chainId} />
                            </Grid>
                            <Grid item xs={xsCalculator}>
                                <FatsoBacking chainId={chainId} />
                            </Grid>
                            <Grid item xs={xsCalculator}>
                                <CurrentIndex chainId={chainId} />
                            </Grid>
                        </Grid>
                    </Paper>

                    <Paper style={{ padding: "0px" }} fullWidth={true} >
                        <TokenInfo isMobileScreen={isMobileScreen} chainId={chainId} />
                    </Paper>
                </Grid>
            </Grid>
            <SafariFooter />
        </Box>
    );
};

const TreasuryDashboard = ({ chainId }) => {
    const isSmallScreen = useMediaQuery("(max-width: 650px)");
    const isVerySmallScreen = useMediaQuery("(max-width: 379px)");

    useEffect(() => {
        ReactGA.send({ hitType: "pageview", page: "/dashboard" });
    }, []);

    return (
        <>
            <PageTitle name="Protocol Metrics" subtitle="Confirm protocol health by auditing supply and reserves" />
            <Container
                style={{
                    paddingLeft: isSmallScreen || isVerySmallScreen ? "0" : "3.3rem",
                    paddingRight: isSmallScreen || isVerySmallScreen ? "0" : "3.3rem",
                }}
            >
                <Box sx={{ mt: "15px" }}>
                    <MetricsDashboard chainId={chainId} />
                </Box>
            </Container>
        </>
    );
};


export default memo(TreasuryDashboard);
