import { useReadContract } from "wagmi";

import { DAO_TREASURY_ADDRESSES } from "../../constants/addresses";
import { abi as TreasuryAbi } from "../../abi/GhostTreasury.json";

import { DecimalBigNumber } from "../../helpers/DecimalBigNumber";

export const useTotalReserves = (chainId) => {
    const { data: totalReservesRaw } = useReadContract({
        abi: TreasuryAbi,
        address: DAO_TREASURY_ADDRESSES[chainId],
        functionName: "totalReserves",
        scopeKey: `totalReserves-${chainId}`,
        chainId: chainId,
    });

    const totalReservesPrepared = totalReservesRaw ? totalReservesRaw : 0n;
    const totalReserves = new DecimalBigNumber(totalReservesPrepared, 9);

    return totalReserves;
};

export const useLpValuation = (chainId, pairAddress, pairSupply) => {
    const { data: valuationRaw } = useReadContract({
        abi: TreasuryAbi,
        address: DAO_TREASURY_ADDRESSES[chainId],
        functionName: "tokenValue",
        scopeKey: `tokenValue-${pairAddress}-${pairSupply.toString()}-${chainId}`,
        args: [
            pairAddress,
            pairSupply,
        ],
        chainId,
    });

    const valuationPrepared = valuationRaw ? valuationRaw : 0n;
    const valuation = new DecimalBigNumber(valuationPrepared, 9);

    return valuation;
}
